@@ -1,5 +1,5 @@
 ## rmatio, a R interface to the C library matio, MAT File I/O Library.
-## Copyright (C) 2013-2014  Stefan Widgren
+## Copyright (C) 2013-2018  Stefan Widgren
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -14,8 +14,11 @@
 ## You should have received a copy of the GNU General Public License
 ## along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-library(rmatio)
-library(Matrix)
+library("rmatio")
+library("Matrix")
+
+## For debugging
+sessionInfo()
 
 ##
 ## Check write and read of cell arrays in MAT5 format:
